@@ -1,10 +1,9 @@
 import datetime
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, Union
 
 import httpx
 
 from ...client import Client
-from ...models.list_completed_jobs_response_200_item import ListCompletedJobsResponse200Item
 from ...types import UNSET, Response, Unset
 
 
@@ -22,6 +21,7 @@ def _get_kwargs(
     created_after: Union[Unset, datetime.datetime] = UNSET,
     success: Union[Unset, bool] = UNSET,
     job_kinds: Union[Unset, str] = UNSET,
+    is_skipped: Union[Unset, bool] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/completed/list".format(client.base_url, workspace=workspace)
 
@@ -47,6 +47,7 @@ def _get_kwargs(
         "created_after": json_created_after,
         "success": success,
         "job_kinds": job_kinds,
+        "is_skipped": is_skipped,
     }
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
@@ -59,25 +60,12 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[ListCompletedJobsResponse200Item]]:
-    if response.status_code == 200:
-        response_200 = []
-        _response_200 = response.json()
-        for response_200_item_data in _response_200:
-            response_200_item = ListCompletedJobsResponse200Item.from_dict(response_200_item_data)
-
-            response_200.append(response_200_item)
-
-        return response_200
-    return None
-
-
-def _build_response(*, response: httpx.Response) -> Response[List[ListCompletedJobsResponse200Item]]:
+def _build_response(*, response: httpx.Response) -> Response[None]:
     return Response(
         status_code=response.status_code,
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=None,
     )
 
 
@@ -95,7 +83,8 @@ def sync_detailed(
     created_after: Union[Unset, datetime.datetime] = UNSET,
     success: Union[Unset, bool] = UNSET,
     job_kinds: Union[Unset, str] = UNSET,
-) -> Response[List[ListCompletedJobsResponse200Item]]:
+    is_skipped: Union[Unset, bool] = UNSET,
+) -> Response[None]:
     kwargs = _get_kwargs(
         client=client,
         workspace=workspace,
@@ -109,6 +98,7 @@ def sync_detailed(
         created_after=created_after,
         success=success,
         job_kinds=job_kinds,
+        is_skipped=is_skipped,
     )
 
     response = httpx.get(
@@ -118,39 +108,6 @@ def sync_detailed(
     return _build_response(response=response)
 
 
-def sync(
-    *,
-    client: Client,
-    workspace: str,
-    order_desc: Union[Unset, bool] = UNSET,
-    created_by: Union[Unset, str] = UNSET,
-    parent_job: Union[Unset, str] = UNSET,
-    script_path_exact: Union[Unset, str] = UNSET,
-    script_path_start: Union[Unset, str] = UNSET,
-    script_hash: Union[Unset, str] = UNSET,
-    created_before: Union[Unset, datetime.datetime] = UNSET,
-    created_after: Union[Unset, datetime.datetime] = UNSET,
-    success: Union[Unset, bool] = UNSET,
-    job_kinds: Union[Unset, str] = UNSET,
-) -> Optional[List[ListCompletedJobsResponse200Item]]:
-    """ """
-
-    return sync_detailed(
-        client=client,
-        workspace=workspace,
-        order_desc=order_desc,
-        created_by=created_by,
-        parent_job=parent_job,
-        script_path_exact=script_path_exact,
-        script_path_start=script_path_start,
-        script_hash=script_hash,
-        created_before=created_before,
-        created_after=created_after,
-        success=success,
-        job_kinds=job_kinds,
-    ).parsed
-
-
 async def asyncio_detailed(
     *,
     client: Client,
@@ -165,7 +122,8 @@ async def asyncio_detailed(
     created_after: Union[Unset, datetime.datetime] = UNSET,
     success: Union[Unset, bool] = UNSET,
     job_kinds: Union[Unset, str] = UNSET,
-) -> Response[List[ListCompletedJobsResponse200Item]]:
+    is_skipped: Union[Unset, bool] = UNSET,
+) -> Response[None]:
     kwargs = _get_kwargs(
         client=client,
         workspace=workspace,
@@ -179,44 +137,10 @@ async def asyncio_detailed(
         created_after=created_after,
         success=success,
         job_kinds=job_kinds,
+        is_skipped=is_skipped,
     )
 
     async with httpx.AsyncClient() as _client:
         response = await _client.get(**kwargs)
 
     return _build_response(response=response)
-
-
-async def asyncio(
-    *,
-    client: Client,
-    workspace: str,
-    order_desc: Union[Unset, bool] = UNSET,
-    created_by: Union[Unset, str] = UNSET,
-    parent_job: Union[Unset, str] = UNSET,
-    script_path_exact: Union[Unset, str] = UNSET,
-    script_path_start: Union[Unset, str] = UNSET,
-    script_hash: Union[Unset, str] = UNSET,
-    created_before: Union[Unset, datetime.datetime] = UNSET,
-    created_after: Union[Unset, datetime.datetime] = UNSET,
-    success: Union[Unset, bool] = UNSET,
-    job_kinds: Union[Unset, str] = UNSET,
-) -> Optional[List[ListCompletedJobsResponse200Item]]:
-    """ """
-
-    return (
-        await asyncio_detailed(
-            client=client,
-            workspace=workspace,
-            order_desc=order_desc,
-            created_by=created_by,
-            parent_job=parent_job,
-            script_path_exact=script_path_exact,
-            script_path_start=script_path_start,
-            script_hash=script_hash,
-            created_before=created_before,
-            created_after=created_after,
-            success=success,
-            job_kinds=job_kinds,
-        )
-    ).parsed
