@@ -20,6 +20,7 @@ def _get_kwargs(
     created_before: Union[Unset, datetime.datetime] = UNSET,
     created_after: Union[Unset, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, str] = UNSET,
+    is_skipped: Union[Unset, bool] = UNSET,
     success: Union[Unset, bool] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/list".format(client.base_url, workspace=workspace)
@@ -44,6 +45,7 @@ def _get_kwargs(
         "created_before": json_created_before,
         "created_after": json_created_after,
         "job_kinds": job_kinds,
+        "is_skipped": is_skipped,
         "success": success,
     }
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
@@ -91,6 +93,7 @@ def sync_detailed(
     created_before: Union[Unset, datetime.datetime] = UNSET,
     created_after: Union[Unset, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, str] = UNSET,
+    is_skipped: Union[Unset, bool] = UNSET,
     success: Union[Unset, bool] = UNSET,
 ) -> Response[List[ListJobsResponse200Item]]:
     kwargs = _get_kwargs(
@@ -104,6 +107,7 @@ def sync_detailed(
         created_before=created_before,
         created_after=created_after,
         job_kinds=job_kinds,
+        is_skipped=is_skipped,
         success=success,
     )
 
@@ -126,6 +130,7 @@ def sync(
     created_before: Union[Unset, datetime.datetime] = UNSET,
     created_after: Union[Unset, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, str] = UNSET,
+    is_skipped: Union[Unset, bool] = UNSET,
     success: Union[Unset, bool] = UNSET,
 ) -> Optional[List[ListJobsResponse200Item]]:
     """ """
@@ -141,6 +146,7 @@ def sync(
         created_before=created_before,
         created_after=created_after,
         job_kinds=job_kinds,
+        is_skipped=is_skipped,
         success=success,
     ).parsed
 
@@ -157,6 +163,7 @@ async def asyncio_detailed(
     created_before: Union[Unset, datetime.datetime] = UNSET,
     created_after: Union[Unset, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, str] = UNSET,
+    is_skipped: Union[Unset, bool] = UNSET,
     success: Union[Unset, bool] = UNSET,
 ) -> Response[List[ListJobsResponse200Item]]:
     kwargs = _get_kwargs(
@@ -170,6 +177,7 @@ async def asyncio_detailed(
         created_before=created_before,
         created_after=created_after,
         job_kinds=job_kinds,
+        is_skipped=is_skipped,
         success=success,
     )
 
@@ -191,6 +199,7 @@ async def asyncio(
     created_before: Union[Unset, datetime.datetime] = UNSET,
     created_after: Union[Unset, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, str] = UNSET,
+    is_skipped: Union[Unset, bool] = UNSET,
     success: Union[Unset, bool] = UNSET,
 ) -> Optional[List[ListJobsResponse200Item]]:
     """ """
@@ -207,6 +216,7 @@ async def asyncio(
             created_before=created_before,
             created_after=created_after,
             job_kinds=job_kinds,
+            is_skipped=is_skipped,
             success=success,
         )
     ).parsed
