@@ -22,6 +22,7 @@ def _get_kwargs(
     parent_hash: Union[Unset, str] = UNSET,
     show_archived: Union[Unset, bool] = UNSET,
     is_template: Union[Unset, bool] = UNSET,
+    is_trigger: Union[Unset, bool] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/scripts/list".format(client.base_url, workspace=workspace)
 
@@ -40,6 +41,7 @@ def _get_kwargs(
         "parent_hash": parent_hash,
         "show_archived": show_archived,
         "is_template": is_template,
+        "is_trigger": is_trigger,
     }
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
@@ -89,6 +91,7 @@ def sync_detailed(
     parent_hash: Union[Unset, str] = UNSET,
     show_archived: Union[Unset, bool] = UNSET,
     is_template: Union[Unset, bool] = UNSET,
+    is_trigger: Union[Unset, bool] = UNSET,
 ) -> Response[List[ListScriptsResponse200Item]]:
     kwargs = _get_kwargs(
         client=client,
@@ -104,6 +107,7 @@ def sync_detailed(
         parent_hash=parent_hash,
         show_archived=show_archived,
         is_template=is_template,
+        is_trigger=is_trigger,
     )
 
     response = httpx.get(
@@ -128,6 +132,7 @@ def sync(
     parent_hash: Union[Unset, str] = UNSET,
     show_archived: Union[Unset, bool] = UNSET,
     is_template: Union[Unset, bool] = UNSET,
+    is_trigger: Union[Unset, bool] = UNSET,
 ) -> Optional[List[ListScriptsResponse200Item]]:
     """ """
 
@@ -145,6 +150,7 @@ def sync(
         parent_hash=parent_hash,
         show_archived=show_archived,
         is_template=is_template,
+        is_trigger=is_trigger,
     ).parsed
 
 
@@ -163,6 +169,7 @@ async def asyncio_detailed(
     parent_hash: Union[Unset, str] = UNSET,
     show_archived: Union[Unset, bool] = UNSET,
     is_template: Union[Unset, bool] = UNSET,
+    is_trigger: Union[Unset, bool] = UNSET,
 ) -> Response[List[ListScriptsResponse200Item]]:
     kwargs = _get_kwargs(
         client=client,
@@ -178,6 +185,7 @@ async def asyncio_detailed(
         parent_hash=parent_hash,
         show_archived=show_archived,
         is_template=is_template,
+        is_trigger=is_trigger,
     )
 
     async with httpx.AsyncClient() as _client:
@@ -201,6 +209,7 @@ async def asyncio(
     parent_hash: Union[Unset, str] = UNSET,
     show_archived: Union[Unset, bool] = UNSET,
     is_template: Union[Unset, bool] = UNSET,
+    is_trigger: Union[Unset, bool] = UNSET,
 ) -> Optional[List[ListScriptsResponse200Item]]:
     """ """
 
@@ -219,5 +228,6 @@ async def asyncio(
             parent_hash=parent_hash,
             show_archived=show_archived,
             is_template=is_template,
+            is_trigger=is_trigger,
         )
     ).parsed
