@@ -18,6 +18,7 @@ class CreateScheduleJsonBody:
     is_flow: bool
     args: CreateScheduleJsonBodyArgs
     offset: Union[Unset, int] = UNSET
+    enabled: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -28,6 +29,7 @@ class CreateScheduleJsonBody:
         args = self.args.to_dict()
 
         offset = self.offset
+        enabled = self.enabled
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -42,6 +44,8 @@ class CreateScheduleJsonBody:
         )
         if offset is not UNSET:
             field_dict["offset"] = offset
+        if enabled is not UNSET:
+            field_dict["enabled"] = enabled
 
         return field_dict
 
@@ -60,6 +64,8 @@ class CreateScheduleJsonBody:
 
         offset = d.pop("offset", UNSET)
 
+        enabled = d.pop("enabled", UNSET)
+
         create_schedule_json_body = cls(
             path=path,
             schedule=schedule,
@@ -67,6 +73,7 @@ class CreateScheduleJsonBody:
             is_flow=is_flow,
             args=args,
             offset=offset,
+            enabled=enabled,
         )
 
         create_schedule_json_body.additional_properties = d
