@@ -22,6 +22,7 @@ class CreateScriptJsonBody:
     schema: Union[Unset, CreateScriptJsonBodySchema] = UNSET
     is_template: Union[Unset, bool] = UNSET
     lock: Union[Unset, List[str]] = UNSET
+    is_trigger: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -41,6 +42,8 @@ class CreateScriptJsonBody:
         if not isinstance(self.lock, Unset):
             lock = self.lock
 
+        is_trigger = self.is_trigger
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -60,6 +63,8 @@ class CreateScriptJsonBody:
             field_dict["is_template"] = is_template
         if lock is not UNSET:
             field_dict["lock"] = lock
+        if is_trigger is not UNSET:
+            field_dict["is_trigger"] = is_trigger
 
         return field_dict
 
@@ -87,6 +92,8 @@ class CreateScriptJsonBody:
 
         lock = cast(List[str], d.pop("lock", UNSET))
 
+        is_trigger = d.pop("is_trigger", UNSET)
+
         create_script_json_body = cls(
             path=path,
             summary=summary,
@@ -97,6 +104,7 @@ class CreateScriptJsonBody:
             schema=schema,
             is_template=is_template,
             lock=lock,
+            is_trigger=is_trigger,
         )
 
         create_script_json_body.additional_properties = d
