@@ -1,7 +1,8 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, List, Type, TypeVar, Union, cast
 
 import attr
 
+from ..models.flow_status_modules_item_iterator import FlowStatusModulesItemIterator
 from ..models.flow_status_modules_item_type import FlowStatusModulesItemType
 from ..types import UNSET, Unset
 
@@ -15,6 +16,8 @@ class FlowStatusModulesItem:
     type: FlowStatusModulesItemType
     job: Union[Unset, str] = UNSET
     event: Union[Unset, str] = UNSET
+    iterator: Union[Unset, FlowStatusModulesItemIterator] = UNSET
+    forloop_jobs: Union[Unset, List[str]] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -22,6 +25,13 @@ class FlowStatusModulesItem:
 
         job = self.job
         event = self.event
+        iterator: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.iterator, Unset):
+            iterator = self.iterator.to_dict()
+
+        forloop_jobs: Union[Unset, List[str]] = UNSET
+        if not isinstance(self.forloop_jobs, Unset):
+            forloop_jobs = self.forloop_jobs
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -34,6 +44,10 @@ class FlowStatusModulesItem:
             field_dict["job"] = job
         if event is not UNSET:
             field_dict["event"] = event
+        if iterator is not UNSET:
+            field_dict["iterator"] = iterator
+        if forloop_jobs is not UNSET:
+            field_dict["forloop_jobs"] = forloop_jobs
 
         return field_dict
 
@@ -46,10 +60,19 @@ class FlowStatusModulesItem:
 
         event = d.pop("event", UNSET)
 
+        iterator: Union[Unset, FlowStatusModulesItemIterator] = UNSET
+        _iterator = d.pop("iterator", UNSET)
+        if not isinstance(_iterator, Unset):
+            iterator = FlowStatusModulesItemIterator.from_dict(_iterator)
+
+        forloop_jobs = cast(List[str], d.pop("forloop_jobs", UNSET))
+
         flow_status_modules_item = cls(
             type=type,
             job=job,
             event=event,
+            iterator=iterator,
+            forloop_jobs=forloop_jobs,
         )
 
         flow_status_modules_item.additional_properties = d
