@@ -18,6 +18,8 @@ class GetVariableResponse200:
     extra_perms: GetVariableResponse200ExtraPerms
     value: Union[Unset, str] = UNSET
     description: Union[Unset, str] = UNSET
+    account: Union[Unset, str] = UNSET
+    is_oauth: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -28,6 +30,8 @@ class GetVariableResponse200:
 
         value = self.value
         description = self.description
+        account = self.account
+        is_oauth = self.is_oauth
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -43,6 +47,10 @@ class GetVariableResponse200:
             field_dict["value"] = value
         if description is not UNSET:
             field_dict["description"] = description
+        if account is not UNSET:
+            field_dict["account"] = account
+        if is_oauth is not UNSET:
+            field_dict["is_oauth"] = is_oauth
 
         return field_dict
 
@@ -61,6 +69,10 @@ class GetVariableResponse200:
 
         description = d.pop("description", UNSET)
 
+        account = d.pop("account", UNSET)
+
+        is_oauth = d.pop("is_oauth", UNSET)
+
         get_variable_response_200 = cls(
             workspace_id=workspace_id,
             path=path,
@@ -68,6 +80,8 @@ class GetVariableResponse200:
             extra_perms=extra_perms,
             value=value,
             description=description,
+            account=account,
+            is_oauth=is_oauth,
         )
 
         get_variable_response_200.additional_properties = d
