@@ -15,6 +15,7 @@ class ListResourceResponse200Item:
 
     path: str
     resource_type: str
+    is_oauth: bool
     workspace_id: Union[Unset, str] = UNSET
     description: Union[Unset, str] = UNSET
     value: Union[Unset, ListResourceResponse200ItemValue] = UNSET
@@ -24,6 +25,7 @@ class ListResourceResponse200Item:
     def to_dict(self) -> Dict[str, Any]:
         path = self.path
         resource_type = self.resource_type
+        is_oauth = self.is_oauth
         workspace_id = self.workspace_id
         description = self.description
         value: Union[Unset, Dict[str, Any]] = UNSET
@@ -40,6 +42,7 @@ class ListResourceResponse200Item:
             {
                 "path": path,
                 "resource_type": resource_type,
+                "is_oauth": is_oauth,
             }
         )
         if workspace_id is not UNSET:
@@ -60,6 +63,8 @@ class ListResourceResponse200Item:
 
         resource_type = d.pop("resource_type")
 
+        is_oauth = d.pop("is_oauth")
+
         workspace_id = d.pop("workspace_id", UNSET)
 
         description = d.pop("description", UNSET)
@@ -77,6 +82,7 @@ class ListResourceResponse200Item:
         list_resource_response_200_item = cls(
             path=path,
             resource_type=resource_type,
+            is_oauth=is_oauth,
             workspace_id=workspace_id,
             description=description,
             value=value,
