@@ -27,6 +27,7 @@ class Script:
     is_template: bool
     extra_perms: ScriptExtraPerms
     language: ScriptLanguage
+    is_trigger: bool
     workspace_id: Union[Unset, str] = UNSET
     parent_hashes: Union[Unset, List[str]] = UNSET
     description: Union[Unset, str] = UNSET
@@ -50,6 +51,7 @@ class Script:
 
         language = self.language.value
 
+        is_trigger = self.is_trigger
         workspace_id = self.workspace_id
         parent_hashes: Union[Unset, List[str]] = UNSET
         if not isinstance(self.parent_hashes, Unset):
@@ -78,6 +80,7 @@ class Script:
                 "is_template": is_template,
                 "extra_perms": extra_perms,
                 "language": language,
+                "is_trigger": is_trigger,
             }
         )
         if workspace_id is not UNSET:
@@ -120,6 +123,8 @@ class Script:
 
         language = ScriptLanguage(d.pop("language"))
 
+        is_trigger = d.pop("is_trigger")
+
         workspace_id = d.pop("workspace_id", UNSET)
 
         parent_hashes = cast(List[str], d.pop("parent_hashes", UNSET))
@@ -147,6 +152,7 @@ class Script:
             is_template=is_template,
             extra_perms=extra_perms,
             language=language,
+            is_trigger=is_trigger,
             workspace_id=workspace_id,
             parent_hashes=parent_hashes,
             description=description,
